You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@accumulo.apache.org by ct...@apache.org on 2013/07/17 04:33:40 UTC

[38/50] [abbrv] git commit: ACCUMULO-1564 Fixing types (JWDP -> JDWP)

ACCUMULO-1564 Fixing types (JWDP -> JDWP)


git-svn-id: https://svn.apache.org/repos/asf/accumulo/trunk@1502407 13f79535-47bb-0310-9956-ffa450edef68


Project: http://git-wip-us.apache.org/repos/asf/accumulo/repo
Commit: http://git-wip-us.apache.org/repos/asf/accumulo/commit/e56edc10
Tree: http://git-wip-us.apache.org/repos/asf/accumulo/tree/e56edc10
Diff: http://git-wip-us.apache.org/repos/asf/accumulo/diff/e56edc10

Branch: refs/heads/ACCUMULO-1496
Commit: e56edc10682db342da6f76d00abe58f4963f203f
Parents: fb2c0c7
Author: Corey J. Nolet <cj...@apache.org>
Authored: Fri Jul 12 01:26:54 2013 +0000
Committer: Corey J. Nolet <cj...@apache.org>
Committed: Fri Jul 12 01:26:54 2013 +0000

----------------------------------------------------------------------
 .../accumulo/minicluster/MiniAccumuloCluster.java   |  2 +-
 .../accumulo/minicluster/MiniAccumuloConfig.java    | 16 ++++++++--------
 .../accumulo/minicluster/MiniAccumuloRunner.java    |  6 +++---
 .../minicluster/MiniAccumuloClusterTest.java        |  2 +-
 4 files changed, 13 insertions(+), 13 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/accumulo/blob/e56edc10/minicluster/src/main/java/org/apache/accumulo/minicluster/MiniAccumuloCluster.java
----------------------------------------------------------------------
diff --git a/minicluster/src/main/java/org/apache/accumulo/minicluster/MiniAccumuloCluster.java b/minicluster/src/main/java/org/apache/accumulo/minicluster/MiniAccumuloCluster.java
index c492e1b..8da22e0 100644
--- a/minicluster/src/main/java/org/apache/accumulo/minicluster/MiniAccumuloCluster.java
+++ b/minicluster/src/main/java/org/apache/accumulo/minicluster/MiniAccumuloCluster.java
@@ -180,7 +180,7 @@ public class MiniAccumuloCluster {
     List<String> jvmOpts = new ArrayList<String>();
     jvmOpts.add("-Xmx" + config.getMemory(serverType));
 
-    if (config.isJWDPEnabled()) {
+    if (config.isJDWPEnabled()) {
       Integer port = PortUtils.getRandomFreePort();
       jvmOpts.addAll(buildRemoteDebugParams(port));
       debugPorts.add(new Pair<ServerType,Integer>(serverType, port));

http://git-wip-us.apache.org/repos/asf/accumulo/blob/e56edc10/minicluster/src/main/java/org/apache/accumulo/minicluster/MiniAccumuloConfig.java
----------------------------------------------------------------------
diff --git a/minicluster/src/main/java/org/apache/accumulo/minicluster/MiniAccumuloRunner.java b/minicluster/src/main/java/org/apache/accumulo/minicluster/MiniAccumuloRunner.java
index b02a7ab..1402b53 100644
--- a/minicluster/src/main/java/org/apache/accumulo/minicluster/MiniAccumuloRunner.java
+++ b/minicluster/src/main/java/org/apache/accumulo/minicluster/MiniAccumuloRunner.java
@@ -44,7 +44,7 @@ import com.google.common.io.Files;
  * instanceName=testInstance
  * numTServers=1
  * zooKeeperPort=3191
- * jwdpEnabled=true
+ * jdwpEnabled=true
  * zooKeeperMemory=128M
  * tserverMemory=256M
  * masterMemory=128M
@@ -110,8 +110,8 @@ public class MiniAccumuloRunner {
       config.setNumTservers(Integer.parseInt(opts.prop.getProperty("numTServers")));
     if (opts.prop.containsKey("zooKeeperPort"))
       config.setZooKeeperPort(Integer.parseInt(opts.prop.getProperty("zooKeeperPort")));
-    if (opts.prop.containsKey("jwdpEnabled"))
-      config.setJWDPEnabled(Boolean.parseBoolean(opts.prop.getProperty("jwdpEnabled")));
+    if (opts.prop.containsKey("jdwpEnabled"))
+      config.setJDWPEnabled(Boolean.parseBoolean(opts.prop.getProperty("jdwpEnabled")));
     if (opts.prop.containsKey("zooKeeperMemory"))
       setMemoryOnConfig(config, opts.prop.getProperty("zooKeeperMemory"), ServerType.ZOOKEEPER);
     if (opts.prop.containsKey("tserverMemory"))

http://git-wip-us.apache.org/repos/asf/accumulo/blob/e56edc10/minicluster/src/test/java/org/apache/accumulo/minicluster/MiniAccumuloClusterTest.java
----------------------------------------------------------------------
diff --git a/minicluster/src/test/java/org/apache/accumulo/minicluster/MiniAccumuloClusterTest.java b/minicluster/src/test/java/org/apache/accumulo/minicluster/MiniAccumuloClusterTest.java
index a031f41..10237b1 100644
--- a/minicluster/src/test/java/org/apache/accumulo/minicluster/MiniAccumuloClusterTest.java
+++ b/minicluster/src/test/java/org/apache/accumulo/minicluster/MiniAccumuloClusterTest.java
@@ -59,7 +59,7 @@ public class MiniAccumuloClusterTest {
     Logger.getLogger("org.apache.zookeeper").setLevel(Level.ERROR);
 
     folder.create();
-    MiniAccumuloConfig config = new MiniAccumuloConfig(folder.getRoot(), "superSecret").setJWDPEnabled(true);
+    MiniAccumuloConfig config = new MiniAccumuloConfig(folder.getRoot(), "superSecret").setJDWPEnabled(true);
     accumulo = new MiniAccumuloCluster(config);
     accumulo.start();
   }
diff --git a/minicluster/src/main/java/org/apache/accumulo/minicluster/MiniAccumuloConfig.java b/minicluster/src/main/java/org/apache/accumulo/minicluster/MiniAccumuloConfig.java
index 4defc35..f183b4e 100644
--- a/minicluster/src/main/java/org/apache/accumulo/minicluster/MiniAccumuloConfig.java
+++ b/minicluster/src/main/java/org/apache/accumulo/minicluster/MiniAccumuloConfig.java
@@ -41,7 +41,7 @@ public class MiniAccumuloConfig {
   private int numTservers = 2;
   private Map<ServerType,Long> memoryConfig = new HashMap<ServerType,Long>();
   
-  private boolean jwdpEnabled = false;
+  private boolean jdwpEnabled = false;
   
   private String instanceName = "miniInstance";
   
@@ -332,23 +332,23 @@ public class MiniAccumuloConfig {
   }
   
   /**
    * @return is the current configuration in jwdpEnabled mode?
    * 
    * @since 1.6.0
    */
-  public boolean isJWDPEnabled() {
-    return jwdpEnabled;
+  public boolean isJDWPEnabled() {
+    return jdwpEnabled;
   }
   
   /**
    * @param jwdpEnabled
    *          should the processes run remote jwdpEnabled servers?
    * @return the current instance
    * 
    * @since 1.6.0
    */
-  public MiniAccumuloConfig setJWDPEnabled(boolean jwdpEnabled) {
-    this.jwdpEnabled = jwdpEnabled;
+  public MiniAccumuloConfig setJDWPEnabled(boolean jdwpEnabled) {
+    this.jdwpEnabled = jdwpEnabled;
     return this;
   }
   

http://git-wip-us.apache.org/repos/asf/accumulo/blob/e56edc10/minicluster/src/main/java/org/apache/accumulo/minicluster/MiniAccumuloRunner.java
----------------------------------------------------------------------
@@ -332,23 +332,23 @@ public class MiniAccumuloConfig {
   
   /**
-   * @return is the current configuration in jwdpEnabled mode?
+   * @return is the current configuration in jdwpEnabled mode?
    * 
    * @since 1.6.0
@@ -332,23 +332,23 @@ public class MiniAccumuloConfig {
   
   /**
-   * @param jwdpEnabled
-   *          should the processes run remote jwdpEnabled servers?
+   * @param jdwpEnabled
+   *          should the processes run remote jdwpEnabled servers?
    * @return the current instance
    * 